@@ -4,10 +4,12 @@ import os
 import Pyro4
 
 from pyage.core import address
-from pyage.core.agent import   generate_agents, AggregateAgent, unnamed_agents, Agent
+from pyage.core.agent.agent import   generate_agents, unnamed_agents, Agent
+from pyage.core.agent.aggregate import AggregateAgent
 from pyage.core.locator import  ParentLocator
 from pyage.core.migration import Pyro4Migration
-from pyage.core.statistics import SimpleStatistics
+from pyage.core.statistics import  TimeStatistics
+from pyage.core.stop_condition import StepLimitStopCondition
 from pyage.solutions.evolution.crossover import  AverageFloatCrossover
 from pyage.solutions.evolution.evaluation import  FloatRastriginEvaluation
 from pyage.solutions.evolution.initializer import  FloatInitializer
@@ -21,14 +23,15 @@ logger.debug("AGGREGATE, %s agents", agents_count)
 
 agents = generate_agents("agent", agents_count, AggregateAgent)
 aggregated_agents = unnamed_agents(2, Agent)
-step_limit = lambda: 500
+
+stop_condition = lambda: StepLimitStopCondition(100)
 
 size = 500
 operators = lambda: [FloatRastriginEvaluation(), TournamentSelection(size=55, tournament_size=30),
                      AverageFloatCrossover(size=size), UniformFloatMutation(probability=0.05, radius=1)]
-initializer = lambda: FloatInitializer(20, size, -10, 10)
+initializer = lambda: FloatInitializer(500, size, -10, 10)
 
-address_provider = address.AddressProvider
+address_provider = address.HashAddressProvider
 
 migration = Pyro4Migration
 locator = ParentLocator
@@ -37,4 +40,4 @@ ns_hostname = lambda: os.environ['NS_HOSTNAME']
 pyro_daemon = Pyro4.Daemon()
 daemon = lambda: pyro_daemon
 
-stats = SimpleStatistics
\ No newline at end of file
+stats = TimeStatistics
\ No newline at end of file
