@@ -8,6 +8,7 @@ from pyage.core.agent import   generate_agents, Agent
 from pyage.core.locator import Pyro4Locator
 from pyage.core.migration import  NoMigration
 from pyage.core.statistics import SimpleStatistics
+from pyage.core.stop_condition import StepLimitStopCondition
 from pyage.solutions.evolution.crossover import  AverageFloatCrossover
 from pyage.solutions.evolution.evaluation import  FloatRastriginEvaluation
 from pyage.solutions.evolution.initializer import  FloatInitializer
@@ -20,14 +21,15 @@ agents_count = int(os.environ['AGENTS'])
 logger.debug("AGGREGATE, %s agents", agents_count)
 
 agents = generate_agents("agent", agents_count, Agent)
-step_limit = lambda: 500
+
+stop_condition = lambda: StepLimitStopCondition(500)
 
 size = 500
 operators = lambda: [FloatRastriginEvaluation(), TournamentSelection(size=125, tournament_size=125),
                      AverageFloatCrossover(size=size), UniformFloatMutation(probability=0.1, radius=1)]
-initializer = lambda: FloatInitializer(10, size, -10, 10)
+initializer = lambda: FloatInitializer(500, size, -10, 10)
 
-address_provider = address.AddressProvider
+address_provider = address.HashAddressProvider
 
 migration = NoMigration
 locator = Pyro4Locator
